ChangeSet 1.946.3.6, 2002/12/26 12:13:26-08:00, greg@kroah.com

[PATCH] USB: convert visor driver to use dev_err() and dev_info() macros


diff -Nru a/drivers/usb/serial/visor.c b/drivers/usb/serial/visor.c
--- a/drivers/usb/serial/visor.c	Fri Dec 27 23:57:59 2002
+++ b/drivers/usb/serial/visor.c	Fri Dec 27 23:57:59 2002
@@ -303,7 +303,7 @@
 
 	if (!port->read_urb) {
 		/* this is needed for some brain dead Sony devices */
-		err ("Device lied about number of ports, please use a lower one.");
+		dev_err(port->dev, "Device lied about number of ports, please use a lower one.\n");
 		return -ENODEV;
 	}
 
@@ -327,8 +327,8 @@
 			   visor_read_bulk_callback, port);
 	result = usb_submit_urb(port->read_urb, GFP_KERNEL);
 	if (result) {
-		err("%s - failed submitting read urb, error %d",
-		    __FUNCTION__, result);
+		dev_err(port->dev, "%s - failed submitting read urb, error %d\n",
+			__FUNCTION__, result);
 		goto exit;
 	}
 	
@@ -336,8 +336,8 @@
 		dbg("%s - adding interrupt input for treo", __FUNCTION__);
 		result = usb_submit_urb(port->interrupt_in_urb, GFP_KERNEL);
 		if (result)
-			err("%s - failed submitting interrupt urb, error %d",
-			    __FUNCTION__, result);
+			dev_err(port->dev, "%s - failed submitting interrupt urb, error %d\n",
+				__FUNCTION__, result);
 	}
 exit:	
 	return result;
@@ -363,7 +363,7 @@
 		 * device is still here */
 		transfer_buffer =  kmalloc (0x12, GFP_KERNEL);
 		if (!transfer_buffer) {
-			err("%s - kmalloc(%d) failed.", __FUNCTION__, 0x12);
+			dev_err(port->dev, "%s - kmalloc(%d) failed.\n", __FUNCTION__, 0x12);
 		} else {
 			/* send a shutdown message to the device */
 			usb_control_msg (serial->dev,
@@ -380,7 +380,7 @@
 			usb_unlink_urb (port->interrupt_in_urb);
 	}
 	/* Uncomment the following line if you want to see some statistics in your syslog */
-	/* info ("Bytes In = %d  Bytes Out = %d", bytes_in, bytes_out); */
+	/* dev_info (port->dev, "Bytes In = %d  Bytes Out = %d\n", bytes_in, bytes_out); */
 }
 
 
@@ -395,13 +395,13 @@
 
 	buffer = kmalloc (count, GFP_ATOMIC);
 	if (!buffer) {
-		err ("out of memory");
+		dev_err(port->dev, "out of memory\n");
 		return -ENOMEM;
 	}
 
 	urb = usb_alloc_urb(0, GFP_ATOMIC);
 	if (!urb) {
-		err ("no more free urbs");
+		dev_err(port->dev, "no more free urbs\n");
 		kfree (buffer);
 		return -ENOMEM;
 	}
@@ -427,8 +427,8 @@
 	/* send it down the pipe */
 	status = usb_submit_urb(urb, GFP_ATOMIC);
 	if (status) {
-		err("%s - usb_submit_urb(write bulk) failed with status = %d",
-		    __FUNCTION__, status);
+		dev_err(port->dev, "%s - usb_submit_urb(write bulk) failed with status = %d\n",
+			__FUNCTION__, status);
 		count = status;
 	} else {
 		bytes_out += count;
@@ -539,7 +539,7 @@
 			   visor_read_bulk_callback, port);
 	result = usb_submit_urb(port->read_urb, GFP_ATOMIC);
 	if (result)
-		err("%s - failed resubmitting read urb, error %d", __FUNCTION__, result);
+		dev_err(port->dev, "%s - failed resubmitting read urb, error %d\n", __FUNCTION__, result);
 	return;
 }
 
@@ -577,8 +577,8 @@
 exit:
 	result = usb_submit_urb (urb, GFP_ATOMIC);
 	if (result)
-		err("%s - Error %d submitting interrupt urb",
-		    __FUNCTION__, result);
+		dev_err(urb->dev->dev, "%s - Error %d submitting interrupt urb\n",
+			__FUNCTION__, result);
 }
 
 static void visor_throttle (struct usb_serial_port *port)
@@ -597,18 +597,19 @@
 	port->read_urb->dev = port->serial->dev;
 	result = usb_submit_urb(port->read_urb, GFP_ATOMIC);
 	if (result)
-		err("%s - failed submitting read urb, error %d", __FUNCTION__, result);
+		dev_err(port->dev, "%s - failed submitting read urb, error %d\n", __FUNCTION__, result);
 }
 
 static int visor_probe (struct usb_serial *serial)
 {
+	struct device *dev = &serial->dev->dev;
 	int response;
 	int i;
 	int num_ports;
 	unsigned char *transfer_buffer =  kmalloc (256, GFP_KERNEL);
 
 	if (!transfer_buffer) {
-		err("%s - kmalloc(%d) failed.", __FUNCTION__, 256);
+		dev_err(*dev, "%s - kmalloc(%d) failed.\n", __FUNCTION__, 256);
 		return -ENOMEM;
 	}
 
@@ -621,14 +622,14 @@
 	response = usb_control_msg (serial->dev, usb_rcvctrlpipe(serial->dev, 0), VISOR_GET_CONNECTION_INFORMATION,
 					0xc2, 0x0000, 0x0000, transfer_buffer, 0x12, 300);
 	if (response < 0) {
-		err("%s - error getting connection information", __FUNCTION__);
+		dev_err(*dev, "%s - error getting connection information\n", __FUNCTION__);
 	} else {
 		struct visor_connection_info *connection_info = (struct visor_connection_info *)transfer_buffer;
 		char *string;
 
 		le16_to_cpus(&connection_info->num_ports);
 		num_ports = connection_info->num_ports;
-		info("%s: Number of ports: %d", serial->type->name, connection_info->num_ports);
+		dev_info(*dev, "%s: Number of ports: %d\n", serial->type->name, connection_info->num_ports);
 		for (i = 0; i < num_ports; ++i) {
 			switch (connection_info->connections[i].port_function_id) {
 				case VISOR_FUNCTION_GENERIC:
@@ -650,8 +651,8 @@
 					string = "unknown";
 					break;	
 			}
-			info("%s: port %d, is for %s use", serial->type->name,
-			     connection_info->connections[i].port, string);
+			dev_info(*dev, "%s: port %d, is for %s use\n", serial->type->name,
+				 connection_info->connections[i].port, string);
 		/* save off our num_ports info so that we can use it in the calc_num_ports call */
 		serial->private = (void *)(long)num_ports;
 		}
@@ -666,7 +667,7 @@
 					    0xc2, 0x0000, 0x0000, transfer_buffer, 
 					    0x14, 300);
 		if (response < 0) {
-			err("%s - error getting first unknown palm command", __FUNCTION__);
+			dev_err(*dev, "%s - error getting first unknown palm command\n", __FUNCTION__);
 		} else {
 			usb_serial_debug_data (__FILE__, __FUNCTION__, 0x14, transfer_buffer);
 		}
@@ -675,7 +676,7 @@
 					    0xc2, 0x0000, 0x0000, transfer_buffer, 
 					    0x14, 300);
 		if (response < 0) {
-			err("%s - error getting second unknown palm command", __FUNCTION__);
+			dev_err(*dev, "%s - error getting second unknown palm command\n", __FUNCTION__);
 		} else {
 			usb_serial_debug_data (__FILE__, __FUNCTION__, 0x14, transfer_buffer);
 		}
@@ -685,7 +686,7 @@
 	response = usb_control_msg (serial->dev, usb_rcvctrlpipe(serial->dev, 0), VISOR_REQUEST_BYTES_AVAILABLE,
 					0xc2, 0x0000, 0x0005, transfer_buffer, 0x02, 300);
 	if (response < 0) {
-		err("%s - error getting bytes available request", __FUNCTION__);
+		dev_err(*dev, "%s - error getting bytes available request\n", __FUNCTION__);
 	}
 
 	kfree (transfer_buffer);
@@ -707,6 +708,7 @@
 
 static int clie_3_5_startup (struct usb_serial *serial)
 {
+	struct device *dev = &serial->dev->dev;
 	int result;
 	u8 data;
 
@@ -721,11 +723,11 @@
 				  USB_REQ_GET_CONFIGURATION, USB_DIR_IN,
 				  0, 0, &data, 1, HZ * 3);
 	if (result < 0) {
-		err("%s: get config number failed: %d", __FUNCTION__, result);
+		dev_err(*dev, "%s: get config number failed: %d\n", __FUNCTION__, result);
 		return result;
 	}
 	if (result != 1) {
-		err("%s: get config number bad return length: %d", __FUNCTION__, result);
+		dev_err(*dev, "%s: get config number bad return length: %d\n", __FUNCTION__, result);
 		return -EIO;
 	}
 
@@ -735,11 +737,11 @@
 				  USB_DIR_IN | USB_RECIP_INTERFACE,
 				  0, 0, &data, 1, HZ * 3);
 	if (result < 0) {
-		err("%s: get interface number failed: %d", __FUNCTION__, result);
+		dev_err(*dev, "%s: get interface number failed: %d\n", __FUNCTION__, result);
 		return result;
 	}
 	if (result != 1) {
-		err("%s: get interface number bad return length: %d", __FUNCTION__, result);
+		dev_err(*dev, "%s: get interface number bad return length: %d\n", __FUNCTION__, result);
 		return -EIO;
 	}
 
